
// ---------------------------------------------------------
// Programa Base para el uso del modulo Sonoff con Virtuino
// Diego Maroto. BilbaoMakers 2017
// ---------------------------------------------------------

#include <ESP8266WiFi.h>
#include "Virtuino_ESP_WifiServer.h"

const char* ssid = "SSID-WIFI";    
const char* password = "wifi-passwd";
WiFiServer server(8000);

Virtuino_ESP_WifiServer virtuino(&server);

// Variable para el estado del rele
int storedValueRelay=0;

void setup() {
   //----- Virtuino settings
  virtuino.DEBUG=true;                         // Monitor de estado puerto serie.
  virtuino.password="1234";                    // Password para el servidor HTTP. Solo numeros y caracteres standard.
                                               
  Serial.begin(9600);                          // Arrancar el puerto serie para el Debug.
  delay(10);

  // Configurar los pines del LED y el Rele
  pinMode(D6,OUTPUT);             // Pin de gobierno del Rele.
  pinMode(D7,OUTPUT);             // Pin de gobierno del LED.

  //----  Configuracion y conexion a la WIFI
  
  Serial.println("Conectando a la wifi "+String(ssid));
  
  IPAddress ip(192, 168, 1, 100);            // Direccion IP para el modulo Sonoff.
  IPAddress gateway(192, 168, 1, 1);         // Puerta de enlace de nuestra red.
  IPAddress subnet(255, 255, 255, 0);        // Mascara de red.
  WiFi.config(ip, gateway, subnet);          // Configuracion. Para DHCP deshabilitar esta linea.
  
  WiFi.mode(WIFI_STA);                       // Configurar como cliente wifi.
  WiFi.begin(ssid, password);
   while (WiFi.status() != WL_CONNECTED) {
     delay(500);
     Serial.print(".");
    }
   Serial.println("");
   Serial.println("WiFi conectada");
   Serial.println(WiFi.localIP());
  
  // Arrancar el servidor HTTP que conecta con Virtuino
  server.begin();
  Serial.println("Servidor HTTP iniciado");

  // Poner las salidas en un estado conocido
  digitalWrite(D7,1); // Led Verde encendido
  digitalWrite(D6,0); // Rele Apagado

   delay(2000);
}


void loop() {
  virtuino.run();

   int v=virtuino.vDigitalMemoryRead(0);              // Leer el VM0 de Virtuino
   if (v!=storedValueRelay) {                          
    Serial.println("Rele cambiado al estado"+String(v));
    
      if (v==1) {
        digitalWrite(D6,0);
        digitalWrite(D7,0);
      }
    
      else {
        digitalWrite(D6,1);
        digitalWrite(D7,1);
      }
    
    storedValueRelay=v;
   }

}


